@@ -1,7 +1,7 @@
 package Treex::Block::W2A::EN::Lemmatize;
-BEGIN {
-  $Treex::Block::W2A::EN::Lemmatize::VERSION = '0.08171';
-}
+$Treex::Block::W2A::EN::Lemmatize::VERSION = '0.13095';
+use strict;
+use warnings;
 use Moose;
 use Treex::Core::Common;
 extends 'Treex::Core::Block';
@@ -42,7 +42,7 @@ Treex::Block::W2A::EN::Lemmatize - wrapper for rule based lemmatizer for English
 
 =head1 VERSION
 
-version 0.08171
+version 0.13095
 
 =head1 DESCRIPTION
 
@@ -79,4 +79,4 @@ David Mareček <marecek@ufal.mff.cuni.cz>
 
 Copyright © 2008 - 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
