@@ -1,10 +1,8 @@
 package Treex::EN;
-BEGIN {
-  $Treex::EN::VERSION = '0.08171';
-}
+$Treex::EN::VERSION = '0.13095';
 use strict;
 use warnings;
-use Treex::Unilang 0.08170;
+use Treex::Unilang;
 
 1;
 
@@ -23,7 +21,7 @@ Treex::EN - collection of blocks for processing English
 
 =head1 VERSION
 
-version 0.08171
+version 0.13095
 
 =head1 DESCRIPTION
 
@@ -35,4 +33,4 @@ Tomáš Kraut <kraut@ufal.mff.cuni.cz>
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
