@@ -1,7 +1,7 @@
 package Treex::Tool::EnglishMorpho::Analysis;
-BEGIN {
-  $Treex::Tool::EnglishMorpho::Analysis::VERSION = '0.08171';
-}
+$Treex::Tool::EnglishMorpho::Analysis::VERSION = '0.13095';
+use strict;
+use warnings;
 use Moose;
 
 use Treex::Core::Log;
@@ -178,7 +178,7 @@ Treex::Tool::EnglishMorpho::Analysis - rule based morphological analyzer for Eng
 
 =head1 VERSION
 
-version 0.08171
+version 0.13095
 
 =head1 SYNOPSIS
 
@@ -219,4 +219,4 @@ Tomáš Kraut <kraut@ufal.mff.cuni.cz>
 
 Copyright © 2008-2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
