@@ -1,7 +1,7 @@
 package Treex::Tool::Segment::EN::RuleBased;
-BEGIN {
-  $Treex::Tool::Segment::EN::RuleBased::VERSION = '0.08171';
-}
+$Treex::Tool::Segment::EN::RuleBased::VERSION = '0.13095';
+use strict;
+use warnings;
 use utf8;
 use Moose;
 use Treex::Core::Common;
@@ -35,7 +35,7 @@ Treex::Tool::Segment::EN::RuleBased - rule based sentence segmenter for English
 
 =head1 VERSION
 
-version 0.08171
+version 0.13095
 
 =head1 DESCRIPTION
 
@@ -55,4 +55,4 @@ Martin Popel <popel@ufal.mff.cuni.cz>
 
 Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
-This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
\ No newline at end of file
+This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
